@@ -237,6 +237,10 @@ class PPIMBC(TransformerMixin, BaseEstimator):
     # data - The data provided by user
     # Y - Target variable
     def fit(self, data, Y):
+        # If user passed a numpy matrix then convert to pandas dataframe and proceed
+        if not isinstance(data, pd.DataFrame):
+            data = pd.DataFrame({'Column'+str(i): data[:, i-1] for i in range(1, len(data[0])+1)})
+        
         # for a value of 0, no CV is applied
         if self.cv!= 0:
             # Find MB for each fold in parallel
@@ -534,6 +538,10 @@ class PPIMBR(TransformerMixin, BaseEstimator):
     # data - The data provided by user
     # Y - Target variable
     def fit(self, data, Y):
+        # If user passed a numpy matrix then convert to pandas dataframe and proceed
+        if not isinstance(data, pd.DataFrame):
+            data = pd.DataFrame({'Column'+str(i): data[:, i-1] for i in range(1, len(data[0])+1)})
+            
         # for a value of 0, no CV is applied
         if self.cv!= 0:
             # Find MB for each fold in parallel
